@@ -3,7 +3,7 @@ package URI;
 use strict;
 use warnings;
 
-our $VERSION = '5.07';
+our $VERSION = '5.08';
 
 our ($ABS_REMOTE_LEADING_DOTS, $ABS_ALLOW_RELATIVE_SCHEME, $DEFAULT_QUERY_FORM_DELIMITER);
 
@@ -916,7 +916,8 @@ query-related sub-components.
 
 The I<news>, I<nntp> and I<snews> URI schemes are specified in
 <draft-gilman-news-url-01> and will hopefully be available as an RFC
-2396 based specification soon.
+2396 based specification soon. (Update: as of April 2010, they are in
+L<RFC 5538|https://tools.ietf.org/html/rfc5538>.
 
 C<URI> objects belonging to the news scheme support the common,
 generic and server methods.  In addition, they provide some methods to
@@ -926,6 +927,10 @@ access the path: $uri->group and $uri->message.
 
 See I<news> scheme.
 
+=item B<nntps>:
+
+See I<news> scheme and L<RFC 5538|https://tools.ietf.org/html/rfc5538>.
+
 =item B<pop>:
 
 The I<pop> URI scheme is specified in RFC 2384. The scheme is used to
